==> ggeffects_1.5.2.tar.gz: ggeffects/tests/testthat/_snaps/print_test_predictions-ordinal.md <==
# print hypothesis_test ordinal outcome

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by Type          | Contrast
      ------------------------------------------
      Low-Tower-Low-Apartment         |    -0.14
      Low-Tower-Low-Atrium            |    -0.09
      Low-Tower-Low-Terrace           |    -0.27
      Low-Tower-Medium-Tower          |     0.09
      Low-Tower-Medium-Apartment      |     0.12
      Low-Tower-Medium-Atrium         |     0.10
      Low-Tower-Medium-Terrace        |     0.17
      Low-Tower-High-Tower            |     0.04
      Low-Tower-High-Apartment        |     0.16
      Low-Tower-High-Atrium           |     0.12
      Low-Tower-High-Terrace          |     0.23
      Low-Apartment-Low-Atrium        |     0.05
      Low-Apartment-Low-Terrace       |    -0.13
      Low-Apartment-Medium-Tower      |     0.23
      Low-Apartment-Medium-Apartment  |     0.26
      Low-Apartment-Medium-Atrium     |     0.24
      Low-Apartment-Medium-Terrace    |     0.31
      Low-Apartment-High-Tower        |     0.18
      Low-Apartment-High-Apartment    |     0.30
      Low-Apartment-High-Atrium       |     0.26
      Low-Apartment-High-Terrace      |     0.37
      Low-Atrium-Low-Terrace          |    -0.18
      Low-Atrium-Medium-Tower         |     0.18
      Low-Atrium-Medium-Apartment     |     0.21
      Low-Atrium-Medium-Atrium        |     0.19
      Low-Atrium-Medium-Terrace       |     0.26
      Low-Atrium-High-Tower           |     0.13
      Low-Atrium-High-Apartment       |     0.25
      Low-Atrium-High-Atrium          |     0.21
      Low-Atrium-High-Terrace         |     0.32
      Low-Terrace-Medium-Tower        |     0.36
      Low-Terrace-Medium-Apartment    |     0.38
      Low-Terrace-Medium-Atrium       |     0.37
      Low-Terrace-Medium-Terrace      |     0.43
      Low-Terrace-High-Tower          |     0.31
      Low-Terrace-High-Apartment      |     0.42
      Low-Terrace-High-Atrium         |     0.39
      Low-Terrace-High-Terrace        |     0.50
      Medium-Tower-Medium-Apartment   |     0.03
      Medium-Tower-Medium-Atrium      |     0.01
      Medium-Tower-Medium-Terrace     |     0.08
      Medium-Tower-High-Tower         |    -0.05
      Medium-Tower-High-Apartment     |     0.07
      Medium-Tower-High-Atrium        |     0.03
      Medium-Tower-High-Terrace       |     0.14
      Medium-Apartment-Medium-Atrium  |    -0.01
      Medium-Apartment-Medium-Terrace |     0.05
      Medium-Apartment-High-Tower     |    -0.07
      Medium-Apartment-High-Apartment |     0.04
      Medium-Apartment-High-Atrium    |     0.00
      Medium-Apartment-High-Terrace   |     0.12
      Medium-Atrium-Medium-Terrace    |     0.06
      Medium-Atrium-High-Tower        |    -0.06
      Medium-Atrium-High-Apartment    |     0.05
      Medium-Atrium-High-Atrium       |     0.02
      Medium-Atrium-High-Terrace      |     0.13
      Medium-Terrace-High-Tower       |    -0.12
      Medium-Terrace-High-Apartment   |    -0.01
      Medium-Terrace-High-Atrium      |    -0.05
      Medium-Terrace-High-Terrace     |     0.07
      High-Tower-High-Apartment       |     0.11
      High-Tower-High-Atrium          |     0.08
      High-Tower-High-Terrace         |     0.19
      High-Apartment-High-Atrium      |    -0.04
      High-Apartment-High-Terrace     |     0.08
      High-Atrium-High-Terrace        |     0.11
    Message
      
      Contrasts are presented as probabilities.

---

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by Type & x            | Contrast
      ------------------------------------------------
      Low-Terrace-1-Low-Apartment-1         |     0.13
      Low-Terrace-1-Low-Terrace-2           |     0.00
      Low-Terrace-1-Low-Apartment-2         |     0.13
      Low-Terrace-1-Medium-Terrace-1        |     0.43
      Low-Terrace-1-Medium-Apartment-1      |     0.38
      Low-Terrace-1-Medium-Terrace-2        |     0.43
      Low-Terrace-1-Medium-Apartment-2      |     0.38
      Low-Terrace-1-High-Terrace-1          |     0.49
      Low-Terrace-1-High-Apartment-1        |     0.42
      Low-Terrace-1-High-Terrace-2          |     0.49
      Low-Terrace-1-High-Apartment-2        |     0.42
      Low-Apartment-1-Low-Terrace-2         |    -0.12
      Low-Apartment-1-Low-Apartment-2       |     0.00
      Low-Apartment-1-Medium-Terrace-1      |     0.30
      Low-Apartment-1-Medium-Apartment-1    |     0.25
      Low-Apartment-1-Medium-Terrace-2      |     0.30
      Low-Apartment-1-Medium-Apartment-2    |     0.25
      Low-Apartment-1-High-Terrace-1        |     0.37
      Low-Apartment-1-High-Apartment-1      |     0.29
      Low-Apartment-1-High-Terrace-2        |     0.37
      Low-Apartment-1-High-Apartment-2      |     0.29
      Low-Terrace-2-Low-Apartment-2         |     0.13
      Low-Terrace-2-Medium-Terrace-1        |     0.42
      Low-Terrace-2-Medium-Apartment-1      |     0.38
      Low-Terrace-2-Medium-Terrace-2        |     0.42
      Low-Terrace-2-Medium-Apartment-2      |     0.38
      Low-Terrace-2-High-Terrace-1          |     0.49
      Low-Terrace-2-High-Apartment-1        |     0.41
      Low-Terrace-2-High-Terrace-2          |     0.49
      Low-Terrace-2-High-Apartment-2        |     0.41
      Low-Apartment-2-Medium-Terrace-1      |     0.30
      Low-Apartment-2-Medium-Apartment-1    |     0.25
      Low-Apartment-2-Medium-Terrace-2      |     0.30
      Low-Apartment-2-Medium-Apartment-2    |     0.25
      Low-Apartment-2-High-Terrace-1        |     0.37
      Low-Apartment-2-High-Apartment-1      |     0.29
      Low-Apartment-2-High-Terrace-2        |     0.36
      Low-Apartment-2-High-Apartment-2      |     0.29
      Medium-Terrace-1-Medium-Apartment-1   |    -0.05
      Medium-Terrace-1-Medium-Terrace-2     |     0.00
      Medium-Terrace-1-Medium-Apartment-2   |    -0.05
      Medium-Terrace-1-High-Terrace-1       |     0.07
      Medium-Terrace-1-High-Apartment-1     |    -0.01
      Medium-Terrace-1-High-Terrace-2       |     0.07
      Medium-Terrace-1-High-Apartment-2     |    -0.01
      Medium-Apartment-1-Medium-Terrace-2   |     0.05
      Medium-Apartment-1-Medium-Apartment-2 |     0.00
      Medium-Apartment-1-High-Terrace-1     |     0.12
      Medium-Apartment-1-High-Apartment-1   |     0.04
      Medium-Apartment-1-High-Terrace-2     |     0.11
      Medium-Apartment-1-High-Apartment-2   |     0.04
      Medium-Terrace-2-Medium-Apartment-2   |    -0.05
      Medium-Terrace-2-High-Terrace-1       |     0.07
      Medium-Terrace-2-High-Apartment-1     |    -0.01
      Medium-Terrace-2-High-Terrace-2       |     0.07
      Medium-Terrace-2-High-Apartment-2     |    -0.01
      Medium-Apartment-2-High-Terrace-1     |     0.12
      Medium-Apartment-2-High-Apartment-1   |     0.04
      Medium-Apartment-2-High-Terrace-2     |     0.11
      Medium-Apartment-2-High-Apartment-2   |     0.04
      High-Terrace-1-High-Apartment-1       |    -0.08
      High-Terrace-1-High-Terrace-2         |     0.00
      High-Terrace-1-High-Apartment-2       |    -0.08
      High-Apartment-1-High-Terrace-2       |     0.08
      High-Apartment-1-High-Apartment-2     |     0.00
      High-Terrace-2-High-Apartment-2       |    -0.08
    Message
      
      Contrasts are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: Low
      
      Type      | Predicted
      ---------------------
      Tower     |      0.38
      Apartment |      0.52
      Atrium    |      0.47
      Terrace   |      0.64
      
      # Response Level: Medium
      
      Type      | Predicted
      ---------------------
      Tower     |      0.29
      Apartment |      0.26
      Atrium    |      0.27
      Terrace   |      0.21
      
      # Response Level: High
      
      Type      | Predicted
      ---------------------
      Tower     |      0.33
      Apartment |      0.22
      Atrium    |      0.26
      Terrace   |      0.14
    Message
      
      Predictions are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: Low
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.64
      Apartment | 1.00 |      0.52
      Terrace   | 2.00 |      0.64
      Apartment | 2.00 |      0.51
      
      # Response Level: Medium
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.21
      Apartment | 1.00 |      0.26
      Terrace   | 2.00 |      0.21
      Apartment | 2.00 |      0.26
      
      # Response Level: High
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.15
      Apartment | 1.00 |      0.22
      Terrace   | 2.00 |      0.15
      Apartment | 2.00 |      0.23
    Message
      
      Predictions are presented as probabilities.

==> ggeffects_1.7.2.tar.gz: ggeffects/tests/testthat/_snaps/print_test_predictions-ordinal.md <==
# print hypothesis_test ordinal outcome

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by Type          | Contrast
      ------------------------------------------
      Low-Tower-Low-Apartment         |    -0.14
      Low-Tower-Low-Atrium            |    -0.09
      Low-Tower-Low-Terrace           |    -0.27
      Low-Tower-Medium-Tower          |     0.09
      Low-Tower-Medium-Apartment      |     0.12
      Low-Tower-Medium-Atrium         |     0.10
      Low-Tower-Medium-Terrace        |     0.17
      Low-Tower-High-Tower            |     0.04
      Low-Tower-High-Apartment        |     0.16
      Low-Tower-High-Atrium           |     0.12
      Low-Tower-High-Terrace          |     0.23
      Low-Apartment-Low-Atrium        |     0.05
      Low-Apartment-Low-Terrace       |    -0.13
      Low-Apartment-Medium-Tower      |     0.23
      Low-Apartment-Medium-Apartment  |     0.26
      Low-Apartment-Medium-Atrium     |     0.24
      Low-Apartment-Medium-Terrace    |     0.31
      Low-Apartment-High-Tower        |     0.18
      Low-Apartment-High-Apartment    |     0.30
      Low-Apartment-High-Atrium       |     0.26
      Low-Apartment-High-Terrace      |     0.37
      Low-Atrium-Low-Terrace          |    -0.18
      Low-Atrium-Medium-Tower         |     0.18
      Low-Atrium-Medium-Apartment     |     0.21
      Low-Atrium-Medium-Atrium        |     0.19
      Low-Atrium-Medium-Terrace       |     0.26
      Low-Atrium-High-Tower           |     0.13
      Low-Atrium-High-Apartment       |     0.25
      Low-Atrium-High-Atrium          |     0.21
      Low-Atrium-High-Terrace         |     0.32
      Low-Terrace-Medium-Tower        |     0.36
      Low-Terrace-Medium-Apartment    |     0.38
      Low-Terrace-Medium-Atrium       |     0.37
      Low-Terrace-Medium-Terrace      |     0.43
      Low-Terrace-High-Tower          |     0.31
      Low-Terrace-High-Apartment      |     0.42
      Low-Terrace-High-Atrium         |     0.39
      Low-Terrace-High-Terrace        |     0.50
      Medium-Tower-Medium-Apartment   |     0.03
      Medium-Tower-Medium-Atrium      |     0.01
      Medium-Tower-Medium-Terrace     |     0.08
      Medium-Tower-High-Tower         |    -0.05
      Medium-Tower-High-Apartment     |     0.07
      Medium-Tower-High-Atrium        |     0.03
      Medium-Tower-High-Terrace       |     0.14
      Medium-Apartment-Medium-Atrium  |    -0.01
      Medium-Apartment-Medium-Terrace |     0.05
      Medium-Apartment-High-Tower     |    -0.07
      Medium-Apartment-High-Apartment |     0.04
      Medium-Apartment-High-Atrium    |     0.00
      Medium-Apartment-High-Terrace   |     0.12
      Medium-Atrium-Medium-Terrace    |     0.06
      Medium-Atrium-High-Tower        |    -0.06
      Medium-Atrium-High-Apartment    |     0.05
      Medium-Atrium-High-Atrium       |     0.02
      Medium-Atrium-High-Terrace      |     0.13
      Medium-Terrace-High-Tower       |    -0.12
      Medium-Terrace-High-Apartment   |    -0.01
      Medium-Terrace-High-Atrium      |    -0.05
      Medium-Terrace-High-Terrace     |     0.07
      High-Tower-High-Apartment       |     0.11
      High-Tower-High-Atrium          |     0.08
      High-Tower-High-Terrace         |     0.19
      High-Apartment-High-Atrium      |    -0.04
      High-Apartment-High-Terrace     |     0.08
      High-Atrium-High-Terrace        |     0.11
    Message
      
      Contrasts are presented as probabilities (in %-points).

---

    Code
      print(out)
    Output
      # Pairwise comparisons
      
      Response Level by Type & x            | Contrast
      ------------------------------------------------
      Low-Terrace-1-Low-Apartment-1         |     0.13
      Low-Terrace-1-Low-Terrace-2           |     0.00
      Low-Terrace-1-Low-Apartment-2         |     0.13
      Low-Terrace-1-Medium-Terrace-1        |     0.43
      Low-Terrace-1-Medium-Apartment-1      |     0.38
      Low-Terrace-1-Medium-Terrace-2        |     0.43
      Low-Terrace-1-Medium-Apartment-2      |     0.38
      Low-Terrace-1-High-Terrace-1          |     0.49
      Low-Terrace-1-High-Apartment-1        |     0.42
      Low-Terrace-1-High-Terrace-2          |     0.49
      Low-Terrace-1-High-Apartment-2        |     0.42
      Low-Apartment-1-Low-Terrace-2         |    -0.12
      Low-Apartment-1-Low-Apartment-2       |     0.00
      Low-Apartment-1-Medium-Terrace-1      |     0.30
      Low-Apartment-1-Medium-Apartment-1    |     0.25
      Low-Apartment-1-Medium-Terrace-2      |     0.30
      Low-Apartment-1-Medium-Apartment-2    |     0.25
      Low-Apartment-1-High-Terrace-1        |     0.37
      Low-Apartment-1-High-Apartment-1      |     0.29
      Low-Apartment-1-High-Terrace-2        |     0.37
      Low-Apartment-1-High-Apartment-2      |     0.29
      Low-Terrace-2-Low-Apartment-2         |     0.13
      Low-Terrace-2-Medium-Terrace-1        |     0.42
      Low-Terrace-2-Medium-Apartment-1      |     0.38
      Low-Terrace-2-Medium-Terrace-2        |     0.42
      Low-Terrace-2-Medium-Apartment-2      |     0.38
      Low-Terrace-2-High-Terrace-1          |     0.49
      Low-Terrace-2-High-Apartment-1        |     0.41
      Low-Terrace-2-High-Terrace-2          |     0.49
      Low-Terrace-2-High-Apartment-2        |     0.41
      Low-Apartment-2-Medium-Terrace-1      |     0.30
      Low-Apartment-2-Medium-Apartment-1    |     0.25
      Low-Apartment-2-Medium-Terrace-2      |     0.30
      Low-Apartment-2-Medium-Apartment-2    |     0.25
      Low-Apartment-2-High-Terrace-1        |     0.37
      Low-Apartment-2-High-Apartment-1      |     0.29
      Low-Apartment-2-High-Terrace-2        |     0.36
      Low-Apartment-2-High-Apartment-2      |     0.29
      Medium-Terrace-1-Medium-Apartment-1   |    -0.05
      Medium-Terrace-1-Medium-Terrace-2     |     0.00
      Medium-Terrace-1-Medium-Apartment-2   |    -0.05
      Medium-Terrace-1-High-Terrace-1       |     0.07
      Medium-Terrace-1-High-Apartment-1     |    -0.01
      Medium-Terrace-1-High-Terrace-2       |     0.07
      Medium-Terrace-1-High-Apartment-2     |    -0.01
      Medium-Apartment-1-Medium-Terrace-2   |     0.05
      Medium-Apartment-1-Medium-Apartment-2 |     0.00
      Medium-Apartment-1-High-Terrace-1     |     0.12
      Medium-Apartment-1-High-Apartment-1   |     0.04
      Medium-Apartment-1-High-Terrace-2     |     0.11
      Medium-Apartment-1-High-Apartment-2   |     0.04
      Medium-Terrace-2-Medium-Apartment-2   |    -0.05
      Medium-Terrace-2-High-Terrace-1       |     0.07
      Medium-Terrace-2-High-Apartment-1     |    -0.01
      Medium-Terrace-2-High-Terrace-2       |     0.07
      Medium-Terrace-2-High-Apartment-2     |    -0.01
      Medium-Apartment-2-High-Terrace-1     |     0.12
      Medium-Apartment-2-High-Apartment-1   |     0.04
      Medium-Apartment-2-High-Terrace-2     |     0.11
      Medium-Apartment-2-High-Apartment-2   |     0.04
      High-Terrace-1-High-Apartment-1       |    -0.08
      High-Terrace-1-High-Terrace-2         |     0.00
      High-Terrace-1-High-Apartment-2       |    -0.08
      High-Apartment-1-High-Terrace-2       |     0.08
      High-Apartment-1-High-Apartment-2     |     0.00
      High-Terrace-2-High-Apartment-2       |    -0.08
    Message
      
      Contrasts are presented as probabilities (in %-points).

---

    Code
      print(out)
    Output
      
      # Response Level: Low
      
      Type      | Predicted
      ---------------------
      Tower     |      0.38
      Apartment |      0.52
      Atrium    |      0.47
      Terrace   |      0.64
      
      # Response Level: Medium
      
      Type      | Predicted
      ---------------------
      Tower     |      0.29
      Apartment |      0.26
      Atrium    |      0.27
      Terrace   |      0.21
      
      # Response Level: High
      
      Type      | Predicted
      ---------------------
      Tower     |      0.33
      Apartment |      0.22
      Atrium    |      0.26
      Terrace   |      0.14
    Message
      
      Predictions are presented as probabilities.

---

    Code
      print(out)
    Output
      
      # Response Level: Low
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.64
      Apartment | 1.00 |      0.52
      Terrace   | 2.00 |      0.64
      Apartment | 2.00 |      0.51
      
      # Response Level: Medium
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.21
      Apartment | 1.00 |      0.26
      Terrace   | 2.00 |      0.21
      Apartment | 2.00 |      0.26
      
      # Response Level: High
      
      Type      |    x | Predicted
      ----------------------------
      Terrace   | 1.00 |      0.15
      Apartment | 1.00 |      0.22
      Terrace   | 2.00 |      0.15
      Apartment | 2.00 |      0.23
    Message
      
      Predictions are presented as probabilities.
